@@ -5,6 +5,7 @@ from datetime import UTC, datetime, timedelta
 from uuid import UUID, uuid4
 import pytest
 from pydantic import ValidationError
+from orcheo.models import CredentialHealthStatus
 from orcheo.triggers import (
     CronDispatchPlan,
     CronOverlapError,
@@ -23,6 +24,11 @@ from orcheo.triggers import (
     WebhookTriggerConfig,
     WebhookValidationError,
 )
+from orcheo.vault.oauth import (
+    CredentialHealthError,
+    CredentialHealthReport,
+    CredentialHealthResult,
+)
 
 
 def test_webhook_dispatch_validation_and_normalization() -> None:
@@ -57,6 +63,118 @@ def test_webhook_dispatch_validation_and_normalization() -> None:
     assert dispatch.input_payload["source_ip"] == "203.0.113.5"
 
 
+def test_webhook_dispatch_redacts_shared_secret_header() -> None:
+    """Shared secret headers are removed from dispatch payloads."""
+
+    workflow_id = uuid4()
+    layer = TriggerLayer()
+    layer.configure_webhook(
+        workflow_id,
+        WebhookTriggerConfig(
+            shared_secret_header="x-secret",
+            shared_secret="expected",
+        ),
+    )
+    request = WebhookRequest(
+        method="POST",
+        headers={"X-Secret": "expected", "X-Other": "value"},
+        query_params={},
+        payload={},
+        source_ip=None,
+    )
+
+    dispatch = layer.prepare_webhook_dispatch(workflow_id, request)
+
+    assert "x-secret" not in dispatch.input_payload["headers"]
+    assert dispatch.input_payload["headers"]["x-other"] == "value"
+
+
+def test_trigger_layer_blocks_unhealthy_workflows() -> None:
+    workflow_id = uuid4()
+    report = CredentialHealthReport(
+        workflow_id=workflow_id,
+        results=[
+            CredentialHealthResult(
+                credential_id=uuid4(),
+                name="Slack",
+                provider="slack",
+                status=CredentialHealthStatus.UNHEALTHY,
+                last_checked_at=datetime.now(tz=UTC),
+                failure_reason="expired",
+            )
+        ],
+        checked_at=datetime.now(tz=UTC),
+    )
+
+    class Guard:
+        def is_workflow_healthy(self, workflow_id: UUID) -> bool:  # noqa: D401 - simple guard
+            return False
+
+        def get_report(self, workflow_id: UUID) -> CredentialHealthReport | None:
+            return report if workflow_id == report.workflow_id else None
+
+    layer = TriggerLayer(health_guard=Guard())
+    layer.configure_webhook(
+        workflow_id,
+        WebhookTriggerConfig(allowed_methods=["post"]),
+    )
+    request = WebhookRequest(
+        method="POST",
+        headers={},
+        query_params={},
+        payload={},
+        source_ip=None,
+    )
+
+    with pytest.raises(CredentialHealthError):
+        layer.prepare_webhook_dispatch(workflow_id, request)
+
+
+def test_trigger_layer_health_guard_can_be_replaced() -> None:
+    workflow_id = uuid4()
+
+    class Guard:
+        def __init__(self) -> None:
+            self.calls = 0
+
+        def is_workflow_healthy(self, workflow_id: UUID) -> bool:
+            self.calls += 1
+            return True
+
+        def get_report(self, workflow_id: UUID):  # pragma: no cover - unused
+            return None
+
+    guard = Guard()
+    layer = TriggerLayer()
+    layer.set_health_guard(guard)
+    layer.configure_webhook(workflow_id, WebhookTriggerConfig(allowed_methods=["post"]))
+    request = WebhookRequest(
+        method="POST",
+        headers={},
+        query_params={},
+        payload={},
+        source_ip=None,
+    )
+
+    layer.prepare_webhook_dispatch(workflow_id, request)
+    assert guard.calls == 1
+
+
+def test_trigger_layer_allows_missing_health_report() -> None:
+    workflow_id = uuid4()
+
+    class Guard:
+        def is_workflow_healthy(self, workflow_id: UUID) -> bool:
+            return False
+
+        def get_report(self, workflow_id: UUID):
+            return None
+
+    layer = TriggerLayer(health_guard=Guard())
+    # Should not raise since the guard lacks a report explaining the failure.
+    layer._ensure_healthy(workflow_id)
+
+
 def test_cron_dispatch_and_overlap_controls() -> None:
     """Cron dispatch plans honour timezone and overlap guards."""
 
@@ -98,6 +216,26 @@ def test_cron_dispatch_and_overlap_controls() -> None:
     assert next_plans[0].timezone == "UTC"
 
 
+def test_collect_due_cron_dispatches_skips_unhealthy_workflows() -> None:
+    workflow_id = uuid4()
+
+    class Guard:
+        def is_workflow_healthy(self, workflow_id: UUID) -> bool:
+            return False
+
+        def get_report(self, workflow_id: UUID):  # pragma: no cover - unused
+            return None
+
+    layer = TriggerLayer(health_guard=Guard())
+    layer.configure_cron(
+        workflow_id,
+        CronTriggerConfig(expression="* * * * *", timezone="UTC"),
+    )
+
+    plans = layer.collect_due_cron_dispatches(now=datetime.now(tz=UTC))
+    assert plans == []
+
+
 def test_manual_dispatch_plan_resolution() -> None:
     """Manual dispatch plans normalise actor, label, and run payloads."""
 
